# Android bindings

The Glean SDK contains the Kotlin bindings for use by Android applications.
It makes use of the underlying [Rust component](../core/index.md) with a Kotlin-specific API on top.
It also includes integrations into the Android platform.
